@@ -7,7 +7,7 @@ from bson import ObjectId
 import json
 from typing import Dict, Any
 from letschatty.models.utils.types.serializer_type import SerializerType
-from letschatty.models.company.assets.ai_agents.chatty_ai_mode import ChattyAIMode
+from letschatty.models.company.assets.ai_agents_v2.chatty_ai_mode import ChattyAIMode
 
 class ChatAssetType(StrEnum):
     PRODUCT = "product"
@@ -65,4 +65,5 @@ class ContactPointAssignedToChat(AssignedAssetToChat):
     source_id: StrObjectId = Field(frozen=True)
 
 class ChattyAIAgentAssignedToChat(AssignedAssetToChat):
-    mode: ChattyAIMode = Field(default=ChattyAIMode.OFF)
\ No newline at end of file
+    mode: ChattyAIMode = Field(default=ChattyAIMode.OFF)
+    requires_human_intervention: bool = Field(default=False)
\ No newline at end of file
