@@ -3,6 +3,7 @@ from .base.message_base import Message
 from ...utils.types.message_types import MessageType
 from .schema import ChattyContentCentral
 
+
 class CentralNotification(Message):
-    type: str = MessageType.CENTRAL
+    type: MessageType = MessageType.CENTRAL
     content: ChattyContentCentral
\ No newline at end of file
