@@ -186,7 +186,7 @@ class ChattyAssetContainerWithCollection(ChattyAssetBaseContainer[T, P], ABC):
 
     def get_preview_by_id(self, id: str, company_id: StrObjectId, preview_type: Type[P]) -> P:
         """We get the preview for one item and update the last_accessed_at cache"""
-        if not self.cache_config.keep_previews_always_in_memory and self.preview_last_accessed_at_cache < datetime.now(ZoneInfo("UTC")) - timedelta(seconds=self.cache_config.cache_expiration_time_previews):
+        if not self.cache_config.keep_previews_always_in_memory and (self.preview_last_accessed_at_cache < datetime.now(ZoneInfo("UTC")) - timedelta(seconds=self.cache_config.cache_expiration_time_previews) or not self.preview_items):
             logger.debug(f"Clearing previews cache of {self.__class__.__name__}")
             self.update_previews_cache()
         return super().get_preview_by_id(id, company_id=company_id)
@@ -194,7 +194,7 @@ class ChattyAssetContainerWithCollection(ChattyAssetBaseContainer[T, P], ABC):
     def get_all_previews(self, company_id: Optional[StrObjectId]) -> List[Dict[str, Any]]:
         """We get the previews for one company and update the last_accessed_at cache"""
         logger.info(f"Getting all previews for {self.__class__.__name__}")
-        if not self.cache_config.keep_previews_always_in_memory and self.preview_last_accessed_at_cache < datetime.now(ZoneInfo("UTC")) - timedelta(seconds=self.cache_config.cache_expiration_time_previews):
+        if not self.cache_config.keep_previews_always_in_memory and (self.preview_last_accessed_at_cache < datetime.now(ZoneInfo("UTC")) - timedelta(seconds=self.cache_config.cache_expiration_time_previews) or not self.preview_items):
             logger.debug(f"Clearing previews cache of {self.__class__.__name__}")
             self.update_previews_cache()
         previews = super().get_all_previews(company_id=company_id)
@@ -260,8 +260,8 @@ class ChattyAssetContainerWithCollection(ChattyAssetBaseContainer[T, P], ABC):
 
     def update_previews_cache(self):
         """We update the previews cache of all the documents in the collection for all companies"""
-        if not self.cache_config.keep_previews_always_in_memory:
-            return
+        # if not self.cache_config.keep_previews_always_in_memory:
+        #     return
         if not self.preview_type or self.preview_type is None:
             return
         projection = self.preview_type.get_projection()
